# EIDA Consistency Report: `RESIF`

- Seed: `478857`
- Time: `2025-09-08T16:57:31.734097+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `20`
- Inconsistent: `0`
- Score: **100.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `0`

## Dataselect Response Types
- **NoTrace**: `7`
- **SingleTrace**: `13`

---

## Detailed Results
### `Y9.AHUE4.00.EHZ`
- Window: `2009-08-09T00:03:04 → 2009-08-09T00:13:04`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `YI.SG20.00.HHZ`
- Window: `2016-01-18T02:45:13 → 2016-01-18T02:55:13`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `YT.131.00.SHZ`
- Window: `2001-11-01T18:28:41 → 2001-11-01T18:38:41`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `YI.SG11.00.HHZ`
- Window: `2016-02-11T20:08:29 → 2016-02-11T20:18:29`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `YR.ME50.00.HHE`
- Window: `2014-12-08T04:30:59 → 2014-12-08T04:40:59`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XG.03009.00.SPE`
- Window: `2020-03-02T18:10:53 → 2020-03-02T18:20:53`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XG.16037.00.SPZ`
- Window: `2020-03-16T21:16:50 → 2020-03-16T21:26:50`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XG.29092.00.SPE`
- Window: `2020-03-12T00:23:39 → 2020-03-12T00:33:39`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XS.QF09.00.HNZ`
- Window: `2010-03-19T16:22:57 → 2010-03-19T16:32:57`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XG.03125.00.SPN`
- Window: `2020-03-15T10:04:32 → 2020-03-15T10:14:32`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XP.A62.20.DPZ`
- Window: `2014-07-22T00:26:55 → 2014-07-22T00:36:55`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `RA.GBGA.00.HN2`
- Window: `2004-01-23T11:34:16 → 2004-01-23T11:44:16`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `ZH.V11.00.BHZ`
- Window: `2003-07-27T21:16:36 → 2003-07-27T21:26:36`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `ZS.COFF.00.HHZ`
- Window: `2007-09-21T09:54:24 → 2007-09-21T10:04:24`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `XP.B16.10.DPZ`
- Window: `2014-07-18T13:49:29 → 2014-07-18T13:59:29`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z4.01X24.00.DPN`
- Window: `2023-07-03T08:25:51 → 2023-07-03T08:35:51`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `YI.SG07.00.HHN`
- Window: `2015-07-22T19:32:13 → 2015-07-22T19:42:13`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `X7.PW26.00.HHE`
- Window: `2013-03-11T01:47:52 → 2013-03-11T01:57:52`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `3C.THOM.00.HHE`
- Window: `2019-11-20T13:38:52 → 2019-11-20T13:48:52`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XP.A61.20.DPZ`
- Window: `2014-07-21T08:32:13 → 2014-07-21T08:42:13`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`
